# coding: utf-8

# flake8: noqa

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.3.9821"

# import apis into sdk package
from ourskyai_sda_api.api.default_api import DefaultApi

# import ApiClient
from ourskyai_sda_api.api_response import ApiResponse
from ourskyai_sda_api.api_client import ApiClient
from ourskyai_sda_api.configuration import Configuration
from ourskyai_sda_api.exceptions import OpenApiException
from ourskyai_sda_api.exceptions import ApiTypeError
from ourskyai_sda_api.exceptions import ApiValueError
from ourskyai_sda_api.exceptions import ApiKeyError
from ourskyai_sda_api.exceptions import ApiAttributeError
from ourskyai_sda_api.exceptions import ApiException

# import models into sdk package
from ourskyai_sda_api.models.astrometric_offsets import AstrometricOffsets
from ourskyai_sda_api.models.empty_success import EmptySuccess
from ourskyai_sda_api.models.filter_type import FilterType
from ourskyai_sda_api.models.fits_header import FitsHeader
from ourskyai_sda_api.models.image_set_type import ImageSetType
from ourskyai_sda_api.models.location import Location
from ourskyai_sda_api.models.mount_type import MountType
from ourskyai_sda_api.models.observation_bounding_box import ObservationBoundingBox
from ourskyai_sda_api.models.observation_quality import ObservationQuality
from ourskyai_sda_api.models.observation_result import ObservationResult
from ourskyai_sda_api.models.observation_state import ObservationState
from ourskyai_sda_api.models.orbit_type import OrbitType
from ourskyai_sda_api.models.satellite_target_tracking_status import SatelliteTargetTrackingStatus
from ourskyai_sda_api.models.search_completed_reason import SearchCompletedReason
from ourskyai_sda_api.models.shutter_type import ShutterType
from ourskyai_sda_api.models.successful_create import SuccessfulCreate
from ourskyai_sda_api.models.successful_delete import SuccessfulDelete
from ourskyai_sda_api.models.tracking_type import TrackingType
from ourskyai_sda_api.models.v1_blackout_volume_request import V1BlackoutVolumeRequest
from ourskyai_sda_api.models.v1_create_direct_task_instruction_request import V1CreateDirectTaskInstructionRequest
from ourskyai_sda_api.models.v1_create_image_set_image_request import V1CreateImageSetImageRequest
from ourskyai_sda_api.models.v1_create_image_set_image_response import V1CreateImageSetImageResponse
from ourskyai_sda_api.models.v1_create_image_set_request import V1CreateImageSetRequest
from ourskyai_sda_api.models.v1_create_organization_target_request import V1CreateOrganizationTargetRequest
from ourskyai_sda_api.models.v1_create_satellite_target_request import V1CreateSatelliteTargetRequest
from ourskyai_sda_api.models.v1_create_search_instruction_request import V1CreateSearchInstructionRequest
from ourskyai_sda_api.models.v1_create_survey_instruction_request import V1CreateSurveyInstructionRequest
from ourskyai_sda_api.models.v1_create_webhook_configuration_request import V1CreateWebhookConfigurationRequest
from ourskyai_sda_api.models.v1_create_webhook_test_request import V1CreateWebhookTestRequest
from ourskyai_sda_api.models.v1_get_satellite_targets_response import V1GetSatelliteTargetsResponse
from ourskyai_sda_api.models.v1_ground_station_participant import V1GroundStationParticipant
from ourskyai_sda_api.models.v1_hfr_star import V1HFRStar
from ourskyai_sda_api.models.v1_image_file_type import V1ImageFileType
from ourskyai_sda_api.models.v1_image_metadata import V1ImageMetadata
from ourskyai_sda_api.models.v1_image_rejection_reason import V1ImageRejectionReason
from ourskyai_sda_api.models.v1_image_set import V1ImageSet
from ourskyai_sda_api.models.v1_image_set_image import V1ImageSetImage
from ourskyai_sda_api.models.v1_matched_star import V1MatchedStar
from ourskyai_sda_api.models.v1_node_calibration_result import V1NodeCalibrationResult
from ourskyai_sda_api.models.v1_observation_feature import V1ObservationFeature
from ourskyai_sda_api.models.v1_observation_sequence_result import V1ObservationSequenceResult
from ourskyai_sda_api.models.v1_observation_sequence_result_image_sets_inner import V1ObservationSequenceResultImageSetsInner
from ourskyai_sda_api.models.v1_observation_status import V1ObservationStatus
from ourskyai_sda_api.models.v1_observer_location import V1ObserverLocation
from ourskyai_sda_api.models.v1_organization_target import V1OrganizationTarget
from ourskyai_sda_api.models.v1_pixel_coordinates import V1PixelCoordinates
from ourskyai_sda_api.models.v1_plane_scan_request import V1PlaneScanRequest
from ourskyai_sda_api.models.v1_plate_solve_result import V1PlateSolveResult
from ourskyai_sda_api.models.v1_plate_solve_status import V1PlateSolveStatus
from ourskyai_sda_api.models.v1_point import V1Point
from ourskyai_sda_api.models.v1_predicted_streak_location import V1PredictedStreakLocation
from ourskyai_sda_api.models.v1_put_orbit_provider_tle_request import V1PutOrbitProviderTLERequest
from ourskyai_sda_api.models.v1_ric_volume_search_request import V1RicVolumeSearchRequest
from ourskyai_sda_api.models.v1_sip_coefficients import V1SIPCoefficients
from ourskyai_sda_api.models.v1_satellite_calibration_family import V1SatelliteCalibrationFamily
from ourskyai_sda_api.models.v1_satellite_potential import V1SatellitePotential
from ourskyai_sda_api.models.v1_satellite_target import V1SatelliteTarget
from ourskyai_sda_api.models.v1_search_instruction import V1SearchInstruction
from ourskyai_sda_api.models.v1_search_instruction_step import V1SearchInstructionStep
from ourskyai_sda_api.models.v1_state_vector import V1StateVector
from ourskyai_sda_api.models.v1_survey_instruction import V1SurveyInstruction
from ourskyai_sda_api.models.v1_survey_instruction_step import V1SurveyInstructionStep
from ourskyai_sda_api.models.v1_target_correlation import V1TargetCorrelation
from ourskyai_sda_api.models.v1_tdm import V1Tdm
from ourskyai_sda_api.models.v1_time_tagged_ra_dec import V1TimeTaggedRaDec
from ourskyai_sda_api.models.v1_track import V1Track
from ourskyai_sda_api.models.v1_transformation import V1Transformation
from ourskyai_sda_api.models.v1_update_email_configuration_request import V1UpdateEmailConfigurationRequest
from ourskyai_sda_api.models.v1_update_organization_target_request import V1UpdateOrganizationTargetRequest
from ourskyai_sda_api.models.v1_update_satellite_target_request import V1UpdateSatelliteTargetRequest
from ourskyai_sda_api.models.v1_update_webhook_configuration_request import V1UpdateWebhookConfigurationRequest
from ourskyai_sda_api.models.v1_webhook_configuration import V1WebhookConfiguration
from ourskyai_sda_api.models.v1_webhook_log import V1WebhookLog
from ourskyai_sda_api.models.v2_search import V2Search
from ourskyai_sda_api.models.weather_condition import WeatherCondition
from ourskyai_sda_api.models.webhook_auth_type import WebhookAuthType
from ourskyai_sda_api.models.webhook_event import WebhookEvent
