# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class WeatherCondition(str, Enum):
    """
    WeatherCondition
    """

    """
    allowed enum values
    """
    THUNDERSTORM = 'THUNDERSTORM'
    DRIZZLE = 'DRIZZLE'
    RAIN = 'RAIN'
    SNOW = 'SNOW'
    ATMOSPHERE = 'ATMOSPHERE'
    CLEAR = 'CLEAR'
    CLOUDS = 'CLOUDS'

    @classmethod
    def from_json(cls, json_str: str) -> WeatherCondition:
        """Create an instance of WeatherCondition from a JSON string"""
        return WeatherCondition(json.loads(json_str))


