# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ourskyai_sda_api.api.default_api import DefaultApi  # noqa: E501


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_get_uncorrelated_tracks(self) -> None:
        """Test case for get_uncorrelated_tracks

        Get uncorrelated tracks collected by the network.  # noqa: E501
        """
        pass

    def test_v1_create_blackout_volume(self) -> None:
        """Test case for v1_create_blackout_volume

        """
        pass

    def test_v1_create_direct_task_instruction(self) -> None:
        """Test case for v1_create_direct_task_instruction

        """
        pass

    def test_v1_create_image_set(self) -> None:
        """Test case for v1_create_image_set

        """
        pass

    def test_v1_create_image_set_image(self) -> None:
        """Test case for v1_create_image_set_image

        """
        pass

    def test_v1_create_organization_target(self) -> None:
        """Test case for v1_create_organization_target

        """
        pass

    def test_v1_create_satellite_target(self) -> None:
        """Test case for v1_create_satellite_target

        """
        pass

    def test_v1_create_search_instruction(self) -> None:
        """Test case for v1_create_search_instruction

        """
        pass

    def test_v1_create_survey_instruction(self) -> None:
        """Test case for v1_create_survey_instruction

        """
        pass

    def test_v1_create_webhook_configuration(self) -> None:
        """Test case for v1_create_webhook_configuration

        """
        pass

    def test_v1_create_webhook_test(self) -> None:
        """Test case for v1_create_webhook_test

        """
        pass

    def test_v1_delete_blackout_volume(self) -> None:
        """Test case for v1_delete_blackout_volume

        """
        pass

    def test_v1_delete_direct_task_instruction(self) -> None:
        """Test case for v1_delete_direct_task_instruction

        """
        pass

    def test_v1_delete_image_set(self) -> None:
        """Test case for v1_delete_image_set

        """
        pass

    def test_v1_delete_image_set_image(self) -> None:
        """Test case for v1_delete_image_set_image

        """
        pass

    def test_v1_delete_organization_target(self) -> None:
        """Test case for v1_delete_organization_target

        """
        pass

    def test_v1_delete_search_instruction(self) -> None:
        """Test case for v1_delete_search_instruction

        """
        pass

    def test_v1_delete_survey_instruction(self) -> None:
        """Test case for v1_delete_survey_instruction

        """
        pass

    def test_v1_delete_webhook_configuration(self) -> None:
        """Test case for v1_delete_webhook_configuration

        """
        pass

    def test_v1_get_image_metadata(self) -> None:
        """Test case for v1_get_image_metadata

        """
        pass

    def test_v1_get_image_set(self) -> None:
        """Test case for v1_get_image_set

        """
        pass

    def test_v1_get_image_set_image(self) -> None:
        """Test case for v1_get_image_set_image

        """
        pass

    def test_v1_get_image_set_images(self) -> None:
        """Test case for v1_get_image_set_images

        """
        pass

    def test_v1_get_image_sets(self) -> None:
        """Test case for v1_get_image_sets

        """
        pass

    def test_v1_get_node_properties(self) -> None:
        """Test case for v1_get_node_properties

        """
        pass

    def test_v1_get_node_satellite_calibrations(self) -> None:
        """Test case for v1_get_node_satellite_calibrations

        """
        pass

    def test_v1_get_observation_features(self) -> None:
        """Test case for v1_get_observation_features

        """
        pass

    def test_v1_get_observation_sequence_result(self) -> None:
        """Test case for v1_get_observation_sequence_result

        """
        pass

    def test_v1_get_observation_sequence_results(self) -> None:
        """Test case for v1_get_observation_sequence_results

        """
        pass

    def test_v1_get_observation_statuses(self) -> None:
        """Test case for v1_get_observation_statuses

        """
        pass

    def test_v1_get_organization_satellite_potentials(self) -> None:
        """Test case for v1_get_organization_satellite_potentials

        """
        pass

    def test_v1_get_organization_target(self) -> None:
        """Test case for v1_get_organization_target

        """
        pass

    def test_v1_get_organization_targets(self) -> None:
        """Test case for v1_get_organization_targets

        """
        pass

    def test_v1_get_satellite_potentials(self) -> None:
        """Test case for v1_get_satellite_potentials

        """
        pass

    def test_v1_get_satellite_target(self) -> None:
        """Test case for v1_get_satellite_target

        """
        pass

    def test_v1_get_satellite_targets(self) -> None:
        """Test case for v1_get_satellite_targets

        """
        pass

    def test_v1_get_search_instructions(self) -> None:
        """Test case for v1_get_search_instructions

        """
        pass

    def test_v1_get_state_vectors(self) -> None:
        """Test case for v1_get_state_vectors

        """
        pass

    def test_v1_get_survey_instructions(self) -> None:
        """Test case for v1_get_survey_instructions

        """
        pass

    def test_v1_get_tdm(self) -> None:
        """Test case for v1_get_tdm

        """
        pass

    def test_v1_get_tdms(self) -> None:
        """Test case for v1_get_tdms

        """
        pass

    def test_v1_get_webhook_configurations(self) -> None:
        """Test case for v1_get_webhook_configurations

        """
        pass

    def test_v1_get_webhook_logs(self) -> None:
        """Test case for v1_get_webhook_logs

        """
        pass

    def test_v1_put_orbit_provider_tle_orbit(self) -> None:
        """Test case for v1_put_orbit_provider_tle_orbit

        """
        pass

    def test_v1_update_email_configuration(self) -> None:
        """Test case for v1_update_email_configuration

        """
        pass

    def test_v1_update_organization_target(self) -> None:
        """Test case for v1_update_organization_target

        """
        pass

    def test_v1_update_satellite_target(self) -> None:
        """Test case for v1_update_satellite_target

        """
        pass

    def test_v1_update_webhook_configuration(self) -> None:
        """Test case for v1_update_webhook_configuration

        """
        pass

    def test_v2_create_plane_scan(self) -> None:
        """Test case for v2_create_plane_scan

        """
        pass

    def test_v2_create_ric_volume_search(self) -> None:
        """Test case for v2_create_ric_volume_search

        """
        pass

    def test_v2_delete_plane_scan(self) -> None:
        """Test case for v2_delete_plane_scan

        """
        pass

    def test_v2_delete_ric_volume_search(self) -> None:
        """Test case for v2_delete_ric_volume_search

        """
        pass

    def test_v2_get_search(self) -> None:
        """Test case for v2_get_search

        """
        pass

    def test_v2_get_searches(self) -> None:
        """Test case for v2_get_searches

        """
        pass


if __name__ == '__main__':
    unittest.main()
