# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from ourskyai_sda_api.models.v1_ground_station_participant import V1GroundStationParticipant  # noqa: E501

class TestV1GroundStationParticipant(unittest.TestCase):
    """V1GroundStationParticipant unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V1GroundStationParticipant:
        """Test V1GroundStationParticipant
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `V1GroundStationParticipant`
        """
        model = V1GroundStationParticipant()  # noqa: E501
        if include_optional:
            return V1GroundStationParticipant(
                node_id = '',
                location = ourskyai_sda_api.models.location.Location(
                    latitude = 1.337, 
                    longitude = 1.337, 
                    altitude = 1.337, ),
                megapixels = 1.337,
                shutter_type = 'ROLLING',
                pixel_size_microns = 1.337,
                gps_timestamps = True,
                ota_focal_length_mm = 56,
                ota_aperture_mm = 56,
                mount_type = 'ALT_AZ',
                master_flat = '',
                master_dark = '',
                master_bias = '',
                focuser_travel_distance_mm = 56,
                supported_tracking_modes = [
                    'SIDEREAL'
                    ]
            )
        else:
            return V1GroundStationParticipant(
                node_id = '',
                location = ourskyai_sda_api.models.location.Location(
                    latitude = 1.337, 
                    longitude = 1.337, 
                    altitude = 1.337, ),
                megapixels = 1.337,
                shutter_type = 'ROLLING',
                pixel_size_microns = 1.337,
                gps_timestamps = True,
                ota_focal_length_mm = 56,
                ota_aperture_mm = 56,
                mount_type = 'ALT_AZ',
        )
        """

    def testV1GroundStationParticipant(self):
        """Test V1GroundStationParticipant"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
